pub struct HttpsClientStreamBuilder { /* fields omitted */ }A HTTPS connection builder for DNS-over-HTTPS
Return a new builder for DNS-over-HTTPS
Constructs a new TlsStreamBuilder with the associated ClientConfig
Add a custom trusted peer certificate or certificate auhtority.
If this is the 'client' then the 'server' must have it associated as it's identity, or have had the identity signed by this certificate.
Creates a new HttpsStream to the specified name_server
name_server - IP and Port for the remote DNS resolver
dns_name - The DNS name, Subject Public Key Info (SPKI) name, as associated to a certificate
loop_handle - The reactor Core handle
Performs copy-assignment from source. Read more
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static